summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:16:56 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:54 +0200
commit78114a50964bc7bb5d7d99f713bb815ed5a623ef (patch)
tree871f5d697fb8825c02152c43ea0e671319b742cf
parent84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (diff)
downloadkscope-78114a50.tar.gz
kscope-78114a50.zip
Initial TDE conversion
-rw-r--r--acinclude.m4262
-rw-r--r--src/Makefile.am2
-rw-r--r--src/calltreedlg.cpp4
-rw-r--r--src/configfrontend.cpp2
-rw-r--r--src/cscopefrontend.cpp12
-rw-r--r--src/ctagsfrontend.cpp4
-rw-r--r--src/ctagslist.cpp2
-rw-r--r--src/dotfrontend.cpp4
-rw-r--r--src/editormanager.cpp2
-rw-r--r--src/editormanager.h4
-rw-r--r--src/editorpage.cpp10
-rw-r--r--src/editorpage.h6
-rw-r--r--src/editortabs.cpp4
-rw-r--r--src/filelist.cpp2
-rw-r--r--src/fileview.cpp2
-rw-r--r--src/fileview.h2
-rw-r--r--src/fileviewlayout.ui4
-rw-r--r--src/frontend.cpp28
-rw-r--r--src/frontend.h8
-rw-r--r--src/graphwidget.cpp4
-rw-r--r--src/historypage.cpp2
-rw-r--r--src/kscope.cpp14
-rw-r--r--src/kscope.desktop2
-rw-r--r--src/kscope.h8
-rw-r--r--src/kscopeactions.cpp20
-rw-r--r--src/kscopeactions.h22
-rw-r--r--src/kscopeconfig.cpp24
-rw-r--r--src/kscopepixmaps.cpp38
-rw-r--r--src/kscopepixmaps.h4
-rw-r--r--src/kscopeui.rc2
-rw-r--r--src/main.cpp22
-rw-r--r--src/makedlg.cpp4
-rw-r--r--src/newprojectdlg.cpp4
-rw-r--r--src/preferencesdlg.cpp16
-rw-r--r--src/preffont.cpp6
-rw-r--r--src/preffrontend.cpp2
-rw-r--r--src/project.cpp10
-rw-r--r--src/project.h4
-rw-r--r--src/projectbase.h2
-rw-r--r--src/projectfilesdlg.cpp6
-rw-r--r--src/projectmanager.cpp4
-rw-r--r--src/querypage.cpp2
-rw-r--r--src/queryresultsmenu.cpp2
-rw-r--r--src/queryview.cpp2
-rw-r--r--src/queryviewdriver.cpp2
-rw-r--r--src/querywidget.cpp6
-rw-r--r--src/querywidget.h6
-rw-r--r--src/scanprogressdlg.cpp2
-rw-r--r--src/symbolcompletion.cpp2
-rw-r--r--src/symbolcompletion.h4
-rw-r--r--src/symboldlg.cpp2
-rw-r--r--src/tabwidget.cpp2
52 files changed, 308 insertions, 308 deletions
diff --git a/acinclude.m4 b/acinclude.m4
index 4f23692..cd8a512 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -23,8 +23,8 @@ dnl IMPORTANT NOTE:
dnl Please do not modify this file unless you expect your modifications to be
dnl carried into every other module in the repository.
dnl
-dnl Single-module modifications are best placed in configure.in for kdelibs
-dnl and kdebase or configure.in.in if present.
+dnl Single-module modifications are best placed in configure.in for tdelibs
+dnl and tdebase or configure.in.in if present.
# KDE_PATH_X_DIRECT
dnl Internal subroutine of AC_PATH_X.
@@ -103,41 +103,41 @@ ac_x_libraries=],
[LIBS="$ac_save_LIBS"
# First see if replacing the include by lib works.
# Check X11 before X11Rn because it is often a symlink to the current release.
-for ac_dir in `echo "$ac_x_includes" | sed s/include/lib${kdelibsuff}/` \
- /usr/X11/lib${kdelibsuff} \
- /usr/X11R6/lib${kdelibsuff} \
- /usr/X11R5/lib${kdelibsuff} \
- /usr/X11R4/lib${kdelibsuff} \
+for ac_dir in `echo "$ac_x_includes" | sed s/include/lib${tdelibsuff}/` \
+ /usr/X11/lib${tdelibsuff} \
+ /usr/X11R6/lib${tdelibsuff} \
+ /usr/X11R5/lib${tdelibsuff} \
+ /usr/X11R4/lib${tdelibsuff} \
\
- /usr/lib${kdelibsuff}/X11 \
- /usr/lib${kdelibsuff}/X11R6 \
- /usr/lib${kdelibsuff}/X11R5 \
- /usr/lib${kdelibsuff}/X11R4 \
+ /usr/lib${tdelibsuff}/X11 \
+ /usr/lib${tdelibsuff}/X11R6 \
+ /usr/lib${tdelibsuff}/X11R5 \
+ /usr/lib${tdelibsuff}/X11R4 \
\
- /usr/local/X11/lib${kdelibsuff} \
- /usr/local/X11R6/lib${kdelibsuff} \
- /usr/local/X11R5/lib${kdelibsuff} \
- /usr/local/X11R4/lib${kdelibsuff} \
+ /usr/local/X11/lib${tdelibsuff} \
+ /usr/local/X11R6/lib${tdelibsuff} \
+ /usr/local/X11R5/lib${tdelibsuff} \
+ /usr/local/X11R4/lib${tdelibsuff} \
\
- /usr/local/lib${kdelibsuff}/X11 \
- /usr/local/lib${kdelibsuff}/X11R6 \
- /usr/local/lib${kdelibsuff}/X11R5 \
- /usr/local/lib${kdelibsuff}/X11R4 \
+ /usr/local/lib${tdelibsuff}/X11 \
+ /usr/local/lib${tdelibsuff}/X11R6 \
+ /usr/local/lib${tdelibsuff}/X11R5 \
+ /usr/local/lib${tdelibsuff}/X11R4 \
\
- /usr/X386/lib${kdelibsuff} \
- /usr/x386/lib${kdelibsuff} \
- /usr/XFree86/lib${kdelibsuff}/X11 \
+ /usr/X386/lib${tdelibsuff} \
+ /usr/x386/lib${tdelibsuff} \
+ /usr/XFree86/lib${tdelibsuff}/X11 \
\
- /usr/lib${kdelibsuff} \
- /usr/local/lib${kdelibsuff} \
- /usr/unsupported/lib${kdelibsuff} \
- /usr/athena/lib${kdelibsuff} \
- /usr/local/x11r5/lib${kdelibsuff} \
- /usr/lpp/Xamples/lib${kdelibsuff} \
- /lib/usr/lib${kdelibsuff}/X11 \
+ /usr/lib${tdelibsuff} \
+ /usr/local/lib${tdelibsuff} \
+ /usr/unsupported/lib${tdelibsuff} \
+ /usr/athena/lib${tdelibsuff} \
+ /usr/local/x11r5/lib${tdelibsuff} \
+ /usr/lpp/Xamples/lib${tdelibsuff} \
+ /lib/usr/lib${tdelibsuff}/X11 \
\
- /usr/openwin/lib${kdelibsuff} \
- /usr/openwin/share/lib${kdelibsuff} \
+ /usr/openwin/lib${tdelibsuff} \
+ /usr/openwin/share/lib${tdelibsuff} \
; \
do
dnl Don't even attempt the hair of trying to link an X program!
@@ -371,24 +371,24 @@ AC_DEFUN([KDE_1_CHECK_PATHS],
fi
AC_MSG_CHECKING([for KDE libraries installed])
-ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -lkdecore $LIBQT $KDE_TEST_RPATH 1>&5'
+ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -ltdecore $LIBQT $KDE_TEST_RPATH 1>&5'
if AC_TRY_EVAL(ac_link) && test -s conftest; then
AC_MSG_RESULT(yes)
else
AC_MSG_ERROR([your system fails at linking a small KDE application!
Check, if your compiler is installed correctly and if you have used the
-same compiler to compile Qt and kdelibs as you did use now.
+same compiler to compile Qt and tdelibs as you did use now.
For more details about this problem, look at the end of config.log.])
fi
-if eval `KDEDIR= ./conftest 2>&5`; then
+if eval `TDEDIR= ./conftest 2>&5`; then
kde_result=done
else
kde_result=problems
fi
-KDEDIR= ./conftest 2> /dev/null >&5 # make an echo for config.log
+TDEDIR= ./conftest 2> /dev/null >&5 # make an echo for config.log
kde_have_all_paths=yes
KDE_SET_PATHS($kde_result)
@@ -547,11 +547,11 @@ Please check whether you installed aRts correctly or use
AC_DEFUN([KDE_SET_DEFAULT_BINDIRS],
[
kde_default_bindirs="/usr/bin /usr/local/bin /opt/local/bin /usr/X11R6/bin /opt/kde/bin /opt/kde3/bin /usr/kde/bin /usr/local/kde/bin"
- test -n "$KDEDIR" && kde_default_bindirs="$KDEDIR/bin $kde_default_bindirs"
- if test -n "$KDEDIRS"; then
+ test -n "$TDEDIR" && kde_default_bindirs="$TDEDIR/bin $kde_default_bindirs"
+ if test -n "$TDEDIRS"; then
kde_save_IFS=$IFS
IFS=:
- for dir in $KDEDIRS; do
+ for dir in $TDEDIRS; do
kde_default_bindirs="$dir/bin $kde_default_bindirs "
done
IFS=$kde_save_IFS
@@ -602,18 +602,18 @@ AC_DEFUN([KDE_SUBST_PROGRAMS],
fi
if test -n "$kde32ornewer"; then
- KDE_FIND_PATH(kconfig_compiler, KCONFIG_COMPILER, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(kconfig_compiler)])
+ KDE_FIND_PATH(tdeconfig_compiler, KCONFIG_COMPILER, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(tdeconfig_compiler)])
KDE_FIND_PATH(dcopidlng, DCOPIDLNG, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(dcopidlng)])
fi
if test -n "$kde33ornewer"; then
- KDE_FIND_PATH(makekdewidgets, MAKEKDEWIDGETS, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(makekdewidgets)])
+ KDE_FIND_PATH(maketdewidgets, MAKEKDEWIDGETS, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(maketdewidgets)])
AC_SUBST(MAKEKDEWIDGETS)
fi
KDE_FIND_PATH(xmllint, XMLLINT, [${prefix}/bin ${exec_prefix}/bin], [XMLLINT=""])
if test -n "$MEINPROC" -a "$MEINPROC" != "compiled"; then
kde_sharedirs="/usr/share/kde /usr/local/share /usr/share /opt/kde3/share /opt/kde/share $prefix/share"
- test -n "$KDEDIR" && kde_sharedirs="$KDEDIR/share $kde_sharedirs"
+ test -n "$TDEDIR" && kde_sharedirs="$TDEDIR/share $kde_sharedirs"
AC_FIND_FILE(apps/ksgmltools2/customization/kde-chunk.xsl, $kde_sharedirs, KDE_XSL_STYLESHEET)
if test "$KDE_XSL_STYLESHEET" = "NO"; then
KDE_XSL_STYLESHEET=""
@@ -710,7 +710,7 @@ AC_SUBST(kde_templatesdir)
AC_SUBST(kde_servicesdir)
AC_SUBST(kde_servicetypesdir)
AC_SUBST(kde_moduledir)
-AC_SUBST(kdeinitdir, '$(kde_moduledir)')
+AC_SUBST(tdeinitdir, '$(kde_moduledir)')
AC_SUBST(kde_styledir)
AC_SUBST(kde_widgetdir)
if test "$kde_qtver" = 1; then
@@ -937,7 +937,7 @@ mips-sgi-irix6*)
ac_x_includes="."
fi
if test -z "$ac_x_libraries"; then
- ac_x_libraries="/usr/lib${kdelibsuff}"
+ ac_x_libraries="/usr/lib${tdelibsuff}"
fi
esac
#from now on we use our own again
@@ -1418,7 +1418,7 @@ qt_includes=""
AC_ARG_WITH(qt-dir,
AC_HELP_STRING([--with-qt-dir=DIR],[where the root of Qt is installed ]),
[ ac_qt_includes="$withval"/include
- ac_qt_libraries="$withval"/lib${kdelibsuff}
+ ac_qt_libraries="$withval"/lib${tdelibsuff}
ac_qt_bindir="$withval"/bin
])
@@ -1459,7 +1459,7 @@ ac_qt_includes="$qt_incdir"
qt_libdirs=""
for dir in $kde_qt_dirs; do
- qt_libdirs="$qt_libdirs $dir/lib${kdelibsuff} $dir"
+ qt_libdirs="$qt_libdirs $dir/lib${tdelibsuff} $dir"
done
qt_libdirs="$QTLIB $qt_libdirs /usr/X11R6/lib /usr/lib /usr/local/qt/lib $x_libraries"
if test ! "$ac_qt_libraries" = "NO"; then
@@ -1644,11 +1644,11 @@ rm -f actest.ui actest.cpp
AC_MSG_RESULT([$kde_cv_uic_plugins])
if test "$kde_cv_uic_plugins" != yes; then
AC_MSG_ERROR([
-you need to install kdelibs first.
+you need to install tdelibs first.
-If you did install kdelibs, then the Qt version that is picked up by
-this configure is not the same version you used to compile kdelibs.
-The Qt Plugin installed by kdelibs is *ONLY* loadable if it is the
+If you did install tdelibs, then the Qt version that is picked up by
+this configure is not the same version you used to compile tdelibs.
+The Qt Plugin installed by tdelibs is *ONLY* loadable if it is the
_same Qt version_, compiled with the _same compiler_ and the same Qt
configuration settings.
])
@@ -1785,16 +1785,16 @@ AC_CACHE_VAL(ac_cv_have_kde,
if test "$kde_qtver" = 1; then
kde_check_header="ksock.h"
- kde_check_lib="libkdecore.la"
+ kde_check_lib="libtdecore.la"
else
kde_check_header="ksharedptr.h"
- kde_check_lib="libkio.la"
+ kde_check_lib="libtdeio.la"
fi
if test -z "$1"; then
-kde_incdirs="$kde_libs_prefix/include /usr/lib/kde/include /usr/local/kde/include /usr/local/include /usr/kde/include /usr/include/kde /usr/include /opt/kde3/include /opt/kde/include $x_includes $qt_includes"
-test -n "$KDEDIR" && kde_incdirs="$KDEDIR/include $KDEDIR/include/kde $KDEDIR $kde_incdirs"
+kde_incdirs="$kde_libs_prefix/include /usr/lib/kde/include /usr/local/kde/include /usr/local/include /usr/kde/include /usr/include/tde /usr/include /opt/kde3/include /opt/kde/include $x_includes $qt_includes"
+test -n "$TDEDIR" && kde_incdirs="$TDEDIR/include $TDEDIR/include/tde $TDEDIR $kde_incdirs"
kde_incdirs="$ac_kde_includes $kde_incdirs"
AC_FIND_FILE($kde_check_header, $kde_incdirs, kde_incdir)
ac_kde_includes="$kde_incdir"
@@ -1805,8 +1805,8 @@ in the prefix, you've chosen, are no KDE headers installed. This will fail.
So, check this please and use another prefix!])
fi
-kde_libdirs="$kde_libs_prefix/lib${kdelibsuff} /usr/lib/kde/lib${kdelibsuff} /usr/local/kde/lib${kdelibsuff} /usr/kde/lib${kdelibsuff} /usr/lib${kdelibsuff}/kde /usr/lib${kdelibsuff}/kde3 /usr/lib${kdelibsuff} /usr/X11R6/lib${kdelibsuff} /usr/local/lib${kdelibsuff} /opt/kde3/lib${kdelibsuff} /opt/kde/lib${kdelibsuff} /usr/X11R6/kde/lib${kdelibsuff}"
-test -n "$KDEDIR" && kde_libdirs="$KDEDIR/lib${kdelibsuff} $KDEDIR $kde_libdirs"
+kde_libdirs="$kde_libs_prefix/lib${tdelibsuff} /usr/lib/kde/lib${tdelibsuff} /usr/local/kde/lib${tdelibsuff} /usr/kde/lib${tdelibsuff} /usr/lib${tdelibsuff}/kde /usr/lib${tdelibsuff}/kde3 /usr/lib${tdelibsuff} /usr/X11R6/lib${tdelibsuff} /usr/local/lib${tdelibsuff} /opt/kde3/lib${tdelibsuff} /opt/kde/lib${tdelibsuff} /usr/X11R6/kde/lib${tdelibsuff}"
+test -n "$TDEDIR" && kde_libdirs="$TDEDIR/lib${tdelibsuff} $TDEDIR $kde_libdirs"
kde_libdirs="$ac_kde_libraries $libdir $kde_libdirs"
AC_FIND_FILE($kde_check_lib, $kde_libdirs, kde_libdir)
ac_kde_libraries="$kde_libdir"
@@ -1824,7 +1824,7 @@ fi
if test -n "$kde_widgetdir" && test ! -r "$kde_widgetdir/kde3/plugins/designer/kdewidgets.la"; then
AC_MSG_ERROR([
I can't find the designer plugins. These are required and should have been installed
-by kdelibs])
+by tdelibs])
fi
if test -n "$kde_widgetdir"; then
@@ -1839,7 +1839,7 @@ else
ac_kde_includes=$ac_kde_includes ac_kde_libraries=$ac_kde_libraries"
fi
-else dnl test -z $1, e.g. from kdelibs
+else dnl test -z $1, e.g. from tdelibs
ac_cv_have_kde="have_kde=no"
@@ -1979,20 +1979,20 @@ cat > conftest.$ac_ext <<EOF
#include <kapp.h>
int main() {
- printf("kde_htmldir=\\"%s\\"\n", KApplication::kde_htmldir().data());
- printf("kde_appsdir=\\"%s\\"\n", KApplication::kde_appsdir().data());
- printf("kde_icondir=\\"%s\\"\n", KApplication::kde_icondir().data());
- printf("kde_sounddir=\\"%s\\"\n", KApplication::kde_sounddir().data());
- printf("kde_datadir=\\"%s\\"\n", KApplication::kde_datadir().data());
- printf("kde_locale=\\"%s\\"\n", KApplication::kde_localedir().data());
- printf("kde_cgidir=\\"%s\\"\n", KApplication::kde_cgidir().data());
- printf("kde_confdir=\\"%s\\"\n", KApplication::kde_configdir().data());
- printf("kde_mimedir=\\"%s\\"\n", KApplication::kde_mimedir().data());
- printf("kde_toolbardir=\\"%s\\"\n", KApplication::kde_toolbardir().data());
+ printf("kde_htmldir=\\"%s\\"\n", TDEApplication::kde_htmldir().data());
+ printf("kde_appsdir=\\"%s\\"\n", TDEApplication::kde_appsdir().data());
+ printf("kde_icondir=\\"%s\\"\n", TDEApplication::kde_icondir().data());
+ printf("kde_sounddir=\\"%s\\"\n", TDEApplication::kde_sounddir().data());
+ printf("kde_datadir=\\"%s\\"\n", TDEApplication::kde_datadir().data());
+ printf("kde_locale=\\"%s\\"\n", TDEApplication::kde_localedir().data());
+ printf("kde_cgidir=\\"%s\\"\n", TDEApplication::kde_cgidir().data());
+ printf("kde_confdir=\\"%s\\"\n", TDEApplication::kde_configdir().data());
+ printf("kde_mimedir=\\"%s\\"\n", TDEApplication::kde_mimedir().data());
+ printf("kde_toolbardir=\\"%s\\"\n", TDEApplication::kde_toolbardir().data());
printf("kde_wallpaperdir=\\"%s\\"\n",
- KApplication::kde_wallpaperdir().data());
- printf("kde_bindir=\\"%s\\"\n", KApplication::kde_bindir().data());
- printf("kde_partsdir=\\"%s\\"\n", KApplication::kde_partsdir().data());
+ TDEApplication::kde_wallpaperdir().data());
+ printf("kde_bindir=\\"%s\\"\n", TDEApplication::kde_bindir().data());
+ printf("kde_partsdir=\\"%s\\"\n", TDEApplication::kde_partsdir().data());
printf("kde_servicesdir=\\"/tmp/dummy\\"\n");
printf("kde_servicetypesdir=\\"/tmp/dummy\\"\n");
printf("kde_moduledir=\\"/tmp/dummy\\"\n");
@@ -2030,7 +2030,7 @@ AC_CACHE_VAL(kde_cv_have_kdeqtaddon,
kde_cxxflags_safe="$CXXFLAGS"
LIBS="-lkde-qt-addon $LIBQT $LIBS"
- CXXFLAGS="$CXXFLAGS -I$prefix/include -I$prefix/include/kde $all_includes"
+ CXXFLAGS="$CXXFLAGS -I$prefix/include -I$prefix/include/tde $all_includes"
LDFLAGS="$LDFLAGS $all_libraries $USER_LDFLAGS"
AC_TRY_LINK([
@@ -2064,48 +2064,48 @@ AC_DEFUN([KDE_CREATE_LIBS_ALIASES],
if test $kde_qtver = 3; then
case $host in
- *cygwin*) lib_kded="-lkdeinit_kded" ;;
+ *cygwin*) lib_kded="-ltdeinit_kded" ;;
*) lib_kded="" ;;
esac
AC_SUBST(LIB_KDED, $lib_kded)
- AC_SUBST(LIB_KDECORE, "-lkdecore")
- AC_SUBST(LIB_KDEUI, "-lkdeui")
- AC_SUBST(LIB_KIO, "-lkio")
+ AC_SUBST(LIB_TDECORE, "-ltdecore")
+ AC_SUBST(LIB_TDEUI, "-ltdeui")
+ AC_SUBST(LIB_TDEIO, "-ltdeio")
AC_SUBST(LIB_KJS, "-lkjs")
AC_SUBST(LIB_SMB, "-lsmb")
AC_SUBST(LIB_KAB, "-lkab")
- AC_SUBST(LIB_KABC, "-lkabc")
- AC_SUBST(LIB_KHTML, "-lkhtml")
- AC_SUBST(LIB_KSPELL, "-lkspell")
- AC_SUBST(LIB_KPARTS, "-lkparts")
- AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
- AC_SUBST(LIB_KUTILS, "-lkutils")
- AC_SUBST(LIB_KDEPIM, "-lkdepim")
- AC_SUBST(LIB_KIMPROXY, "-lkimproxy")
+ AC_SUBST(LIB_KABC, "-ltdeabc")
+ AC_SUBST(LIB_TDEHTML, "-ltdehtml")
+ AC_SUBST(LIB_TDESPELL, "-ltdespell")
+ AC_SUBST(LIB_TDEPARTS, "-ltdeparts")
+ AC_SUBST(LIB_TDEPRINT, "-ltdeprint")
+ AC_SUBST(LIB_TDEUTILS, "-ltdeutils")
+ AC_SUBST(LIB_TDEPIM, "-ltdepim")
+ AC_SUBST(LIB_TDEIMPROXY, "-ltdeimproxy")
AC_SUBST(LIB_KNEWSTUFF, "-lknewstuff")
- AC_SUBST(LIB_KDNSSD, "-lkdnssd")
- AC_SUBST(LIB_KUNITTEST, "-lkunittest")
+ AC_SUBST(LIB_TDEDNSSD, "-ltdednssd")
+ AC_SUBST(LIB_TDEUNITTEST, "-ltdeunittest")
# these are for backward compatibility
- AC_SUBST(LIB_KSYCOCA, "-lkio")
- AC_SUBST(LIB_KFILE, "-lkio")
+ AC_SUBST(LIB_TDESYCOCA, "-ltdeio")
+ AC_SUBST(LIB_KFILE, "-ltdeio")
elif test $kde_qtver = 2; then
- AC_SUBST(LIB_KDECORE, "-lkdecore")
- AC_SUBST(LIB_KDEUI, "-lkdeui")
- AC_SUBST(LIB_KIO, "-lkio")
- AC_SUBST(LIB_KSYCOCA, "-lksycoca")
+ AC_SUBST(LIB_TDECORE, "-ltdecore")
+ AC_SUBST(LIB_TDEUI, "-ltdeui")
+ AC_SUBST(LIB_TDEIO, "-ltdeio")
+ AC_SUBST(LIB_TDESYCOCA, "-ltdesycoca")
AC_SUBST(LIB_SMB, "-lsmb")
- AC_SUBST(LIB_KFILE, "-lkfile")
+ AC_SUBST(LIB_KFILE, "-ltdefile")
AC_SUBST(LIB_KAB, "-lkab")
- AC_SUBST(LIB_KHTML, "-lkhtml")
- AC_SUBST(LIB_KSPELL, "-lkspell")
- AC_SUBST(LIB_KPARTS, "-lkparts")
- AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
+ AC_SUBST(LIB_TDEHTML, "-ltdehtml")
+ AC_SUBST(LIB_TDESPELL, "-ltdespell")
+ AC_SUBST(LIB_TDEPARTS, "-ltdeparts")
+ AC_SUBST(LIB_TDEPRINT, "-ltdeprint")
else
- AC_SUBST(LIB_KDECORE, "-lkdecore -lXext $(LIB_QT)")
- AC_SUBST(LIB_KDEUI, "-lkdeui $(LIB_KDECORE)")
- AC_SUBST(LIB_KFM, "-lkfm $(LIB_KDECORE)")
- AC_SUBST(LIB_KFILE, "-lkfile $(LIB_KFM) $(LIB_KDEUI)")
- AC_SUBST(LIB_KAB, "-lkab $(LIB_KIMGIO) $(LIB_KDECORE)")
+ AC_SUBST(LIB_TDECORE, "-ltdecore -lXext $(LIB_QT)")
+ AC_SUBST(LIB_TDEUI, "-ltdeui $(LIB_TDECORE)")
+ AC_SUBST(LIB_KFM, "-lkfm $(LIB_TDECORE)")
+ AC_SUBST(LIB_KFILE, "-ltdefile $(LIB_KFM) $(LIB_TDEUI)")
+ AC_SUBST(LIB_KAB, "-lkab $(LIB_KIMGIO) $(LIB_TDECORE)")
fi
])
@@ -2170,7 +2170,7 @@ if test "x$kde_cv_func_$1" = xyes; then
else
case "$1" in
setenv|unsetenv|usleep|random|srandom|seteuid|mkstemps|mkstemp|revoke|vsnprintf|strlcpy|strlcat)
- kde_cv_proto_$1="yes - in libkdefakes"
+ kde_cv_proto_$1="yes - in libtdefakes"
;;
*)
kde_cv_proto_$1=unknown
@@ -2489,7 +2489,7 @@ if eval "test \"`echo $ac_cv_lib_gif`\" = yes"; then
AC_MSG_RESULT(yes)
AC_DEFINE_UNQUOTED(HAVE_LIBGIF, 1, [Define if you have libgif])
else
- AC_MSG_ERROR(You need giflib30. Please install the kdesupport package)
+ AC_MSG_ERROR(You need giflib30. Please install the tdesupport package)
fi
])
@@ -2547,7 +2547,7 @@ AC_FIND_FILE(jpeglib.h, $jpeg_incdirs, jpeg_incdir)
test "x$jpeg_incdir" = xNO && jpeg_incdir=
dnl if headers _and_ libraries are missing, this is no error, and we
-dnl continue with a warning (the user will get no jpeg support in khtml)
+dnl continue with a warning (the user will get no jpeg support in tdehtml)
dnl if only one is missing, it means a configuration error, but we still
dnl only warn
if test -n "$jpeg_incdir" && test -n "$LIBJPEG" ; then
@@ -3447,7 +3447,7 @@ LIBTOOL_SHELL="/bin/sh ./libtool"
KDE_PLUGIN="-avoid-version -module -no-undefined \$(KDE_NO_UNDEFINED) \$(KDE_RPATH) \$(KDE_MT_LDFLAGS)"
AC_SUBST(KDE_PLUGIN)
-# This hack ensures that libtool creates shared libs for kunittest plugins. By default check_LTLIBRARIES makes static libs.
+# This hack ensures that libtool creates shared libs for tdeunittest plugins. By default check_LTLIBRARIES makes static libs.
KDE_CHECK_PLUGIN="\$(KDE_PLUGIN) -rpath \$(libdir)"
AC_SUBST(KDE_CHECK_PLUGIN)
@@ -3457,29 +3457,29 @@ AC_SUBST(AUTOCONF,'$(SHELL) $(top_srcdir)/admin/cvs.sh configure || touch config
AC_DEFUN([KDE_CHECK_LIB64],
[
- kdelibsuff="$kde_libs_suffix"
- if test -z "$kdelibsuff"; then
- kdelibsuff=no
+ tdelibsuff="$kde_libs_suffix"
+ if test -z "$tdelibsuff"; then
+ tdelibsuff=no
fi
AC_ARG_ENABLE(libsuffix,
AC_HELP_STRING([--enable-libsuffix],
[/lib directory suffix (64,32,none[=default])]),
- kdelibsuff=$enableval)
+ tdelibsuff=$enableval)
# TODO: add an auto case that compiles a little C app to check
# where the glibc is
- if test "$kdelibsuff" = "no"; then
- kdelibsuff=
+ if test "$tdelibsuff" = "no"; then
+ tdelibsuff=
fi
- if test -z "$kdelibsuff"; then
+ if test -z "$tdelibsuff"; then
AC_MSG_RESULT([not using lib directory suffix])
AC_DEFINE(KDELIBSUFF, [""], Suffix for lib directories)
else
if test "$libdir" = '${exec_prefix}/lib'; then
- libdir="$libdir${kdelibsuff}"
+ libdir="$libdir${tdelibsuff}"
AC_SUBST([libdir], ["$libdir"]) dnl ugly hack for lib64 platforms
fi
- AC_DEFINE_UNQUOTED(KDELIBSUFF, ["${kdelibsuff}"], Suffix for lib directories)
- AC_MSG_RESULT([using lib directory suffix $kdelibsuff])
+ AC_DEFINE_UNQUOTED(KDELIBSUFF, ["${tdelibsuff}"], Suffix for lib directories)
+ AC_MSG_RESULT([using lib directory suffix $tdelibsuff])
fi
])
@@ -3497,7 +3497,7 @@ AC_CANONICAL_SYSTEM
AC_ARG_PROGRAM
AM_INIT_AUTOMAKE($1, $2)
AM_DISABLE_LIBRARIES
-AC_PREFIX_DEFAULT(${KDEDIR:-/usr/local/kde})
+AC_PREFIX_DEFAULT(${TDEDIR:-/usr/local/kde})
AC_CHECK_COMPILERS
KDE_PROG_LIBTOOL
AM_KDE_WITH_NLS
@@ -4504,7 +4504,7 @@ fi
PYTHONINC=-I$python_incdir
-python_libdirs="$ac_python_dir/lib$kdelibsuff /usr/lib$kdelibsuff /usr/local /usr/lib$kdelibsuff $kde_extra_libs"
+python_libdirs="$ac_python_dir/lib$tdelibsuff /usr/lib$tdelibsuff /usr/local /usr/lib$tdelibsuff $kde_extra_libs"
AC_FIND_FILE(libpython$version.so, $python_libdirs, python_libdir)
if test ! -r $python_libdir/libpython$version.so; then
AC_FIND_FILE(libpython$version.a, $python_libdirs, python_libdir)
@@ -4892,14 +4892,14 @@ AC_DEFUN([KDE_CONF_FILES],
AC_SUBST(CONF_FILES)
])dnl
-dnl This sets the prefix, for arts and kdelibs
+dnl This sets the prefix, for arts and tdelibs
dnl Do NOT use in any other module.
-dnl It only looks at --prefix, KDEDIR and falls back to /usr/local/kde
+dnl It only looks at --prefix, TDEDIR and falls back to /usr/local/kde
AC_DEFUN([KDE_SET_PREFIX_CORE],
[
unset CDPATH
- dnl make $KDEDIR the default for the installation
- AC_PREFIX_DEFAULT(${KDEDIR:-/usr/local/kde})
+ dnl make $TDEDIR the default for the installation
+ AC_PREFIX_DEFAULT(${TDEDIR:-/usr/local/kde})
if test "x$prefix" = "xNONE"; then
prefix=$ac_default_prefix
@@ -4923,25 +4923,25 @@ AC_DEFUN([KDE_SET_PREFIX],
unset CDPATH
dnl We can't give real code to that macro, only a value.
dnl It only matters for --help, since we set the prefix in this function anyway.
- AC_PREFIX_DEFAULT(${KDEDIR:-the kde prefix})
+ AC_PREFIX_DEFAULT(${TDEDIR:-the kde prefix})
KDE_SET_DEFAULT_BINDIRS
if test "x$prefix" = "xNONE"; then
- dnl no prefix given: look for kde-config in the PATH and deduce the prefix from it
- KDE_FIND_PATH(kde-config, KDECONFIG, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(kde-config)], [], prepend)
+ dnl no prefix given: look for tde-config in the PATH and deduce the prefix from it
+ KDE_FIND_PATH(tde-config, KDECONFIG, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(tde-config)], [], prepend)
else
- dnl prefix given: look for kde-config, preferrably in prefix, otherwise in PATH
+ dnl prefix given: look for tde-config, preferrably in prefix, otherwise in PATH
kde_save_PATH="$PATH"
PATH="$exec_prefix/bin:$prefix/bin:$PATH"
- KDE_FIND_PATH(kde-config, KDECONFIG, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(kde-config)], [], prepend)
+ KDE_FIND_PATH(tde-config, KDECONFIG, [$kde_default_bindirs], [KDE_MISSING_PROG_ERROR(tde-config)], [], prepend)
PATH="$kde_save_PATH"
fi
kde_libs_prefix=`$KDECONFIG --prefix`
if test -z "$kde_libs_prefix" || test ! -x "$kde_libs_prefix"; then
- AC_MSG_ERROR([$KDECONFIG --prefix outputed the non existant prefix '$kde_libs_prefix' for kdelibs.
+ AC_MSG_ERROR([$KDECONFIG --prefix outputed the non existant prefix '$kde_libs_prefix' for tdelibs.
This means it has been moved since you installed it.
- This won't work. Please recompile kdelibs for the new prefix.
+ This won't work. Please recompile tdelibs for the new prefix.
])
fi
kde_libs_htmldir=`$KDECONFIG --install html --expandvars`
@@ -4950,7 +4950,7 @@ AC_DEFUN([KDE_SET_PREFIX],
AC_MSG_CHECKING([where to install])
if test "x$prefix" = "xNONE"; then
prefix=$kde_libs_prefix
- AC_MSG_RESULT([$prefix (as returned by kde-config)])
+ AC_MSG_RESULT([$prefix (as returned by tde-config)])
else
dnl --prefix was given. Compare prefixes and warn (in configure.in.bot.end) if different
given_prefix=$prefix
@@ -5607,7 +5607,7 @@ ssl_includes=""
AC_ARG_WITH(ssl-dir,
AC_HELP_STRING([--with-ssl-dir=DIR],[where the root of OpenSSL is installed]),
[ ac_ssl_includes="$withval"/include
- ac_ssl_libraries="$withval"/lib$kdelibsuff
+ ac_ssl_libraries="$withval"/lib$tdelibsuff
])
want_ssl=yes
@@ -5627,7 +5627,7 @@ AC_CACHE_VAL(ac_cv_have_ssl,
AC_FIND_FILE(openssl/ssl.h, $ssl_incdirs, ssl_incdir)
ac_ssl_includes="$ssl_incdir"
- ssl_libdirs="/usr/lib$kdelibsuff /usr/local/lib$kdelibsuff /usr/ssl/lib$kdelibsuff /usr/local/ssl/lib$kdelibsuff $libdir $prefix/lib$kdelibsuff $exec_prefix/lib$kdelibsuff $kde_extra_libs"
+ ssl_libdirs="/usr/lib$tdelibsuff /usr/local/lib$tdelibsuff /usr/ssl/lib$tdelibsuff /usr/local/ssl/lib$tdelibsuff $libdir $prefix/lib$tdelibsuff $exec_prefix/lib$tdelibsuff $kde_extra_libs"
if test ! "$ac_ssl_libraries" = "NO"; then
ssl_libdirs="$ac_ssl_libraries $ssl_libdirs"
fi
diff --git a/src/Makefile.am b/src/Makefile.am
index a1d6d4f..4b7cdd7 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -49,7 +49,7 @@ kscope_SOURCES = autocompletionlayout.ui bookmarksdlg.cpp bookmarkslayout.ui \
symbollayout.ui tabwidget.cpp treewidget.cpp welcomedlg.ui
kscope_LDFLAGS = $(KDE_RPATH) $(all_libraries)
-kscope_LDADD = -lkateinterfaces -lkatepartinterfaces -lktexteditor $(LIB_KDEUI) $(LIB_KPARTS) $(LIB_KIO) $(LIB_KDECORE) $(LIB_QT)
+kscope_LDADD = -lkateinterfaces -lkatepartinterfaces -ltdetexteditor $(LIB_TDEUI) $(LIB_TDEPARTS) $(LIB_TDEIO) $(LIB_TDECORE) $(LIB_QT)
# this is where the desktop file will go
shelldesktopdir = $(kde_appsdir)/Development
diff --git a/src/calltreedlg.cpp b/src/calltreedlg.cpp
index 75c9abb..78d57c2 100644
--- a/src/calltreedlg.cpp
+++ b/src/calltreedlg.cpp
@@ -29,8 +29,8 @@
#include <ntqtoolbutton.h>
#include <ntqbuttongroup.h>
#include <ntqwidgetstack.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
#include "calltreedlg.h"
#include "graphwidget.h"
#include "treewidget.h"
diff --git a/src/configfrontend.cpp b/src/configfrontend.cpp
index 66c9684..2a870a6 100644
--- a/src/configfrontend.cpp
+++ b/src/configfrontend.cpp
@@ -61,7 +61,7 @@ bool ConfigFrontend::run(const TQString& sCscopePath,
bool bCscopeOptsOnly)
{
TQStringList slArgs;
- KStandardDirs sd;
+ TDEStandardDirs sd;
TQString sScript;
// Execute using the user's shell
diff --git a/src/cscopefrontend.cpp b/src/cscopefrontend.cpp
index 79d829e..b25c924 100644
--- a/src/cscopefrontend.cpp
+++ b/src/cscopefrontend.cpp
@@ -27,10 +27,10 @@
#include <ntqfileinfo.h>
#include <ntqtimer.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kglobalsettings.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobalsettings.h>
#include "cscopefrontend.h"
#include "kscopeconfig.h"
#include "configfrontend.h"
@@ -422,9 +422,9 @@ void CscopeProgress::setProgress(int nProgress, int nTotal)
m_pLabel->adjustSize();
m_pLabel->setPaletteBackgroundColor(
- KGlobalSettings::highlightColor());
+ TDEGlobalSettings::highlightColor());
m_pLabel->setPaletteForegroundColor(
- KGlobalSettings::highlightedTextColor());
+ TDEGlobalSettings::highlightedTextColor());
TQTimer::singleShot(1000, this, SLOT(slotShowLabel()));
}
diff --git a/src/ctagsfrontend.cpp b/src/ctagsfrontend.cpp
index 425a435..646dc2a 100644
--- a/src/ctagsfrontend.cpp
+++ b/src/ctagsfrontend.cpp
@@ -26,8 +26,8 @@
***************************************************************************/
#include <ntqfileinfo.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include <kshell.h>
#include "ctagsfrontend.h"
#include "kscopeconfig.h"
diff --git a/src/ctagslist.cpp b/src/ctagslist.cpp
index 0a0ae69..147a9aa 100644
--- a/src/ctagslist.cpp
+++ b/src/ctagslist.cpp
@@ -26,7 +26,7 @@
***************************************************************************/
#include <ntqheader.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "ctagslist.h"
#include "kscopeconfig.h"
#include "kscopepixmaps.h"
diff --git a/src/dotfrontend.cpp b/src/dotfrontend.cpp
index 69e825d..9330730 100644
--- a/src/dotfrontend.cpp
+++ b/src/dotfrontend.cpp
@@ -27,8 +27,8 @@
#include <ntqfileinfo.h>
#include <ntqpaintdevicemetrics.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "dotfrontend.h"
#include "graphwidget.h"
#include "kscopeconfig.h"
diff --git a/src/editormanager.cpp b/src/editormanager.cpp
index 505a6cb..ca781b9 100644
--- a/src/editormanager.cpp
+++ b/src/editormanager.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <ktexteditor/editorchooser.h>
+#include <tdetexteditor/editorchooser.h>
#include <kate/document.h>
#include "editormanager.h"
#include "kscopeconfig.h"
diff --git a/src/editormanager.h b/src/editormanager.h
index 0a2a42b..5136823 100644
--- a/src/editormanager.h
+++ b/src/editormanager.h
@@ -29,9 +29,9 @@
#define EDITORMANAGER_H
#include <ntqwidget.h>
-#include <kparts/partmanager.h>
+#include <tdeparts/partmanager.h>
#include <klibloader.h>
-#include <ktexteditor/document.h>
+#include <tdetexteditor/document.h>
/**
* Creates text editor parts, used to open source files.
diff --git a/src/editorpage.cpp b/src/editorpage.cpp
index a838e76..df69e0c 100644
--- a/src/editorpage.cpp
+++ b/src/editorpage.cpp
@@ -26,11 +26,11 @@
***************************************************************************/
#include <ntqfileinfo.h>
-#include <kdeversion.h>
-#include <ktexteditor/selectioninterface.h>
-#include <ktexteditor/viewcursorinterface.h>
-#include <ktexteditor/popupmenuinterface.h>
-#include <ktexteditor/editinterface.h>
+#include <tdeversion.h>
+#include <tdetexteditor/selectioninterface.h>
+#include <tdetexteditor/viewcursorinterface.h>
+#include <tdetexteditor/popupmenuinterface.h>
+#include <tdetexteditor/editinterface.h>
#include <kate/document.h>
#include <kate/view.h>
#include "editorpage.h"
diff --git a/src/editorpage.h b/src/editorpage.h
index 37a6e65..5c5be31 100644
--- a/src/editorpage.h
+++ b/src/editorpage.h
@@ -33,9 +33,9 @@
#include <ntqsplitter.h>
#include <ntqtabwidget.h>
#include <ntqpopupmenu.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/view.h>
-#include <ktexteditor/markinterfaceextension.h>
+#include <tdetexteditor/document.h>
+#include <tdetexteditor/view.h>
+#include <tdetexteditor/markinterfaceextension.h>
#include "ctagsfrontend.h"
#include "ctagslist.h"
#include "kscopeconfig.h"
diff --git a/src/editortabs.cpp b/src/editortabs.cpp
index af9587c..d72a37f 100644
--- a/src/editortabs.cpp
+++ b/src/editortabs.cpp
@@ -26,8 +26,8 @@
***************************************************************************/
#include <ntqfileinfo.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <kurldrag.h>
#include <kate/document.h>
#include "editortabs.h"
diff --git a/src/filelist.cpp b/src/filelist.cpp
index e9fdb9a..7694d7c 100644
--- a/src/filelist.cpp
+++ b/src/filelist.cpp
@@ -27,7 +27,7 @@
#include <ntqlineedit.h>
#include <ntqfileinfo.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "filelist.h"
#include "kscope.h"
#include "kscopeconfig.h"
diff --git a/src/fileview.cpp b/src/fileview.cpp
index d611e59..d8d4fb6 100644
--- a/src/fileview.cpp
+++ b/src/fileview.cpp
@@ -28,7 +28,7 @@
#include <ntqpushbutton.h>
#include <ntqfileinfo.h>
#include <ntqtabwidget.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
#include "fileview.h"
#include "filelist.h"
#include "kscopepixmaps.h"
diff --git a/src/fileview.h b/src/fileview.h
index ca78783..9044061 100644
--- a/src/fileview.h
+++ b/src/fileview.h
@@ -28,7 +28,7 @@
#ifndef FILEVIEW_H
#define FILEVIEW_H
-#include <kfiletreeview.h>
+#include <tdefiletreeview.h>
#include "fileviewlayout.h"
/**
diff --git a/src/fileviewlayout.ui b/src/fileviewlayout.ui
index 7e49bd1..0649864 100644
--- a/src/fileviewlayout.ui
+++ b/src/fileviewlayout.ui
@@ -108,7 +108,7 @@
</customwidget>
<customwidget>
<class>KFileTreeView</class>
- <header location="global">kfiletreeview.h</header>
+ <header location="global">tdefiletreeview.h</header>
<sizehint>
<width>-1</width>
<height>-1</height>
@@ -131,6 +131,6 @@
<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>filelist.h</includehint>
- <includehint>kfiletreeview.h</includehint>
+ <includehint>tdefiletreeview.h</includehint>
</includehints>
</UI>
diff --git a/src/frontend.cpp b/src/frontend.cpp
index cd01b3b..28e0342 100644
--- a/src/frontend.cpp
+++ b/src/frontend.cpp
@@ -27,7 +27,7 @@
#include <ntqfileinfo.h>
#include <ntqdir.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "frontend.h"
/**
@@ -36,7 +36,7 @@
* @param bAutoDelete (Optional) true to delete the object when the process
* terminates, false (default) otherwise
*/
-Frontend::Frontend(uint nRecordSize, bool bAutoDelete) : KProcess(),
+Frontend::Frontend(uint nRecordSize, bool bAutoDelete) : TDEProcess(),
m_nRecords(0),
m_pHeadToken(NULL),
m_pTailToken(NULL),
@@ -46,16 +46,16 @@ Frontend::Frontend(uint nRecordSize, bool bAutoDelete) : KProcess(),
m_nRecordSize(nRecordSize)
{
// Parse data on the standard output
- connect(this, SIGNAL(receivedStdout(KProcess*, char*, int)), this,
- SLOT(slotReadStdout(KProcess*, char*, int)));
+ connect(this, SIGNAL(receivedStdout(TDEProcess*, char*, int)), this,
+ SLOT(slotReadStdout(TDEProcess*, char*, int)));
// Parse data on the standard error
- connect(this, SIGNAL(receivedStderr(KProcess*, char*, int)), this,
- SLOT(slotReadStderr(KProcess*, char*, int)));
+ connect(this, SIGNAL(receivedStderr(TDEProcess*, char*, int)), this,
+ SLOT(slotReadStderr(TDEProcess*, char*, int)));
// Delete the process object when the process exits
- connect(this, SIGNAL(processExited(KProcess*)), this,
- SLOT(slotProcessExit(KProcess*)));
+ connect(this, SIGNAL(processExited(TDEProcess*)), this,
+ SLOT(slotProcessExit(TDEProcess*)));
}
/**
@@ -99,8 +99,8 @@ bool Frontend::run(const TQString& sName, const TQStringList& slArgs,
setWorkingDirectory(sWorkDir);
// Execute the child process
- if (!start(bBlock ? KProcess::Block : KProcess::NotifyOnExit,
- KProcess::All)) {
+ if (!start(bBlock ? TDEProcess::Block : TDEProcess::NotifyOnExit,
+ TDEProcess::All)) {
m_sError = sName + i18n(": Failed to start process");
return false;
}
@@ -117,7 +117,7 @@ bool Frontend::run(const TQString& sName, const TQStringList& slArgs,
void Frontend::kill()
{
m_bKilled = true;
- KProcess::kill();
+ TDEProcess::kill();
emit aborted();
}
@@ -258,7 +258,7 @@ void Frontend::parseStderr(const TQString& sText)
/**
* Deletes the process object upon the process' exit.
*/
-void Frontend::slotProcessExit(KProcess*)
+void Frontend::slotProcessExit(TDEProcess*)
{
// Allow specialised clean-up by inheriting classes
finalize();
@@ -279,7 +279,7 @@ void Frontend::slotProcessExit(KProcess*)
* The method reads whatever data is queued, and sends it to be interpreted
* by parseStdout().
*/
-void Frontend::slotReadStdout(KProcess*, char* pBuffer, int nSize)
+void Frontend::slotReadStdout(TDEProcess*, char* pBuffer, int nSize)
{
char* pLocalBuf;
TQString sToken;
@@ -350,7 +350,7 @@ void Frontend::slotReadStdout(KProcess*, char* pBuffer, int nSize)
* The method reads whatever data is queued, and sends it to be interpreted
* by parseStderr().
*/
-void Frontend::slotReadStderr(KProcess*, char* pBuffer, int nSize)
+void Frontend::slotReadStderr(TDEProcess*, char* pBuffer, int nSize)
{
TQString sBuf;
diff --git a/src/frontend.h b/src/frontend.h
index 801f49c..1de524b 100644
--- a/src/frontend.h
+++ b/src/frontend.h
@@ -73,7 +73,7 @@ protected:
* @author Elad Lahav
*/
-class Frontend : public KProcess
+class Frontend : public TDEProcess
{
Q_OBJECT
@@ -179,7 +179,7 @@ protected:
virtual void finalize() {}
protected slots:
- virtual void slotProcessExit(KProcess*);
+ virtual void slotProcessExit(TDEProcess*);
private:
/** Determines whether the object should be deleted once the process has
@@ -205,8 +205,8 @@ private:
bool tokenize(char**, int*, TQString&, ParserDelim&);
private slots:
- void slotReadStdout(KProcess*, char*, int);
- void slotReadStderr(KProcess*, char*, int);
+ void slotReadStdout(TDEProcess*, char*, int);
+ void slotReadStderr(TDEProcess*, char*, int);
};
#endif
diff --git a/src/graphwidget.cpp b/src/graphwidget.cpp
index 2481f59..7805ec4 100644
--- a/src/graphwidget.cpp
+++ b/src/graphwidget.cpp
@@ -30,8 +30,8 @@
#include <ntqfile.h>
#include <ntqpainter.h>
#include <ntqtooltip.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include "graphwidget.h"
#include "graphnode.h"
#include "graphedge.h"
diff --git a/src/historypage.cpp b/src/historypage.cpp
index 5095d1c..81a3e87 100644
--- a/src/historypage.cpp
+++ b/src/historypage.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <klocale.h>
+#include <tdelocale.h>
#include "historypage.h"
#include "historyview.h"
diff --git a/src/kscope.cpp b/src/kscope.cpp
index 5e56233..4444810 100644
--- a/src/kscope.cpp
+++ b/src/kscope.cpp
@@ -26,10 +26,10 @@
***************************************************************************/
#include <ntqfile.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemenubar.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include <klineedit.h>
#include <kinputdialog.h>
#include <kxmlguifactory.h>
@@ -899,7 +899,7 @@ void KScope::toggleQueryWindow(bool bShow)
* 3. A list of source files
* @param pArgs Command line arguments
*/
-void KScope::parseCmdLine(KCmdLineArgs* pArgs)
+void KScope::parseCmdLine(TDECmdLineArgs* pArgs)
{
TQString sArg;
TQFileInfo fi;
@@ -1073,7 +1073,7 @@ bool KScope::slotCloseProject()
void KScope::slotExtEdit()
{
TQString sCmdLine;
- KProcess proc;
+ TDEProcess proc;
// Create the command line for the external editor
sCmdLine = Config().getExtEditor();
@@ -1083,7 +1083,7 @@ void KScope::slotExtEdit()
// Run the external editor
proc.setUseShell(true);
proc << sCmdLine;
- proc.start(KProcess::DontCare);
+ proc.start(TDEProcess::DontCare);
}
/**
diff --git a/src/kscope.desktop b/src/kscope.desktop
index 453a4fc..05a14a0 100644
--- a/src/kscope.desktop
+++ b/src/kscope.desktop
@@ -8,5 +8,5 @@ Comment=Source-editing environment for large C projects
Comment[fr]=Editeur de codes sources pour de gros projets en C
GenericName=Source editing environment
GenericName[fr]=Editeur de code source
-Categories=Qt;KDE;Development
+Categories=Qt;TDE;Development
diff --git a/src/kscope.h b/src/kscope.h
index 8b8ee07..20332fb 100644
--- a/src/kscope.h
+++ b/src/kscope.h
@@ -33,10 +33,10 @@
#endif
#include <ntqtimer.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
#include <kapp.h>
-#include <kparts/dockmainwindow.h>
-#include <kparts/part.h>
+#include <tdeparts/dockmainwindow.h>
+#include <tdeparts/part.h>
class ProjectManager;
class EditorTabs;
@@ -79,7 +79,7 @@ public:
void openProject(const TQString&);
void openLastProject();
bool openCscopeOut(const TQString&);
- void parseCmdLine(KCmdLineArgs *pArgs);
+ void parseCmdLine(TDECmdLineArgs *pArgs);
void verifyCscope();
public slots:
diff --git a/src/kscopeactions.cpp b/src/kscopeactions.cpp
index 3caaedd..e74984d 100644
--- a/src/kscopeactions.cpp
+++ b/src/kscopeactions.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <klocale.h>
+#include <tdelocale.h>
#include "kscope.h"
#include "kscopeactions.h"
#include "kscopeconfig.h"
@@ -138,7 +138,7 @@ void KScopeActions::init()
SIGNAL(toggleProject(bool)));
addAction(i18n("&Make Project"),
- "make_kdevelop",
+ "make_tdevelop",
"Ctrl+M",
m_pWindow,
SLOT(slotProjectMake()),
@@ -474,16 +474,16 @@ void KScopeActions::slotEnableFileActions(bool bEnable)
* the action
* @return The newly created action object
*/
-KAction* KScopeActions::addAction(const TQString& sCaption, const char* szIcon,
+TDEAction* KScopeActions::addAction(const TQString& sCaption, const char* szIcon,
const char* szShortcut, TQWidget* pReceiver, const char* szSlot,
const char* szName, const char* szSignal)
{
- KAction* pAction;
+ TDEAction* pAction;
// Create the action
- pAction = new KAction(sCaption,
+ pAction = new TDEAction(sCaption,
szIcon,
- szShortcut == NULL ? KShortcut() : KShortcut(szShortcut),
+ szShortcut == NULL ? TDEShortcut() : TDEShortcut(szShortcut),
pReceiver,
szSlot,
m_pCollection,
@@ -508,16 +508,16 @@ KAction* KScopeActions::addAction(const TQString& sCaption, const char* szIcon,
* the action
* @return The newly created action object
*/
-KToggleAction* KScopeActions::addToggle(const TQString& sCaption,
+TDEToggleAction* KScopeActions::addToggle(const TQString& sCaption,
const char* szIcon, const char* szShortcut, TQWidget* pReceiver,
const char* szSlot, const char* szName, const char* szSignal)
{
- KToggleAction* pAction;
+ TDEToggleAction* pAction;
// Create the action
- pAction = new KToggleAction(sCaption,
+ pAction = new TDEToggleAction(sCaption,
szIcon,
- szShortcut == NULL ? KShortcut() : KShortcut(szShortcut),
+ szShortcut == NULL ? TDEShortcut() : TDEShortcut(szShortcut),
pReceiver,
szSlot,
m_pCollection,
diff --git a/src/kscopeactions.h b/src/kscopeactions.h
index a344dab..3fa17a9 100644
--- a/src/kscopeactions.h
+++ b/src/kscopeactions.h
@@ -28,11 +28,11 @@
#ifndef KSCOPEACTIONS_H
#define KSCOPEACTIONS_H
-#include <kaction.h>
+#include <tdeaction.h>
class KScope;
-typedef TQPtrList<KAction> ActionList;
+typedef TQPtrList<TDEAction> ActionList;
/**
* A helper class for managing KScope's menu commands.
@@ -51,7 +51,7 @@ public:
void initLayoutActions();
void enableExtEditor(bool);
- KToggleAction* getLockAction() { return m_pLockAction; }
+ TDEToggleAction* getLockAction() { return m_pLockAction; }
public slots:
void slotQueryDockToggled(bool);
@@ -66,7 +66,7 @@ signals:
private:
KScope* m_pWindow;
- KActionCollection* m_pCollection;
+ TDEActionCollection* m_pCollection;
/** A list of actions that require an active project. */
ActionList m_lstProjActions;
@@ -75,23 +75,23 @@ private:
ActionList m_lstFileActions;
/** A toggle menu item for locking/unlocking query pages. */
- KToggleAction* m_pLockAction;
+ TDEToggleAction* m_pLockAction;
/** The "Edit in External Editor" menu command. */
- KAction* m_pExtEditAction;
+ TDEAction* m_pExtEditAction;
/** The "Show/Hide File View" menu command. */
- KToggleAction* m_pToggleFileViewAction;
+ TDEToggleAction* m_pToggleFileViewAction;
/** The "Show/Hide Query Window" menu command. */
- KToggleAction* m_pToggleQueryWindowAction;
+ TDEToggleAction* m_pToggleQueryWindowAction;
/** The "Show/Hide Tag List" menu command. */
- KToggleAction* m_pToggleTagListAction;
+ TDEToggleAction* m_pToggleTagListAction;
- KAction* addAction(const TQString&, const char*, const char*, TQWidget*,
+ TDEAction* addAction(const TQString&, const char*, const char*, TQWidget*,
const char*, const char*, const char*);
- KToggleAction* addToggle(const TQString&, const char*, const char*,
+ TDEToggleAction* addToggle(const TQString&, const char*, const char*,
TQWidget*, const char*, const char*, const char*);
};
diff --git a/src/kscopeconfig.cpp b/src/kscopeconfig.cpp
index 924421f..f9ef0d8 100644
--- a/src/kscopeconfig.cpp
+++ b/src/kscopeconfig.cpp
@@ -25,9 +25,9 @@
*
***************************************************************************/
-#include <kconfig.h>
-#include <kapplication.h>
-#include <kglobalsettings.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
+#include <tdeglobalsettings.h>
#include "kscopeconfig.h"
// NOTE:
@@ -141,14 +141,14 @@ void KScopeConfig::load()
{
uint i;
- KConfig* pConf = kapp->config();
+ TDEConfig* pConf = kapp->config();
// Need a working instance to get the system's default font (cannot be
// initialised statically)
- s_cpDef.fonts[FileList] = KGlobalSettings::generalFont();
- s_cpDef.fonts[TagList] = KGlobalSettings::generalFont();
- s_cpDef.fonts[QueryWindow] = KGlobalSettings::generalFont();
- s_cpDef.fonts[Graph] = KGlobalSettings::generalFont();
+ s_cpDef.fonts[FileList] = TDEGlobalSettings::generalFont();
+ s_cpDef.fonts[TagList] = TDEGlobalSettings::generalFont();
+ s_cpDef.fonts[QueryWindow] = TDEGlobalSettings::generalFont();
+ s_cpDef.fonts[Graph] = TDEGlobalSettings::generalFont();
// Read the paths to required executables
pConf->setGroup("Programs");
@@ -237,7 +237,7 @@ void KScopeConfig::store()
{
uint i;
- KConfig* pConf = kapp->config();
+ TDEConfig* pConf = kapp->config();
// Write the paths to required executables
pConf->setGroup("Programs");
@@ -306,7 +306,7 @@ void KScopeConfig::storeWorkspace(KDockMainWindow* pMainWindow)
*/
bool KScopeConfig::isFirstTime()
{
- KConfig* pConf = kapp->config();
+ TDEConfig* pConf = kapp->config();
pConf->setGroup("General");
return pConf->readBoolEntry("FirstTime", true);
@@ -321,7 +321,7 @@ bool KScopeConfig::isFirstTime()
*/
bool KScopeConfig::showWelcomeDlg()
{
- KConfig* pConf = kapp->config();
+ TDEConfig* pConf = kapp->config();
pConf->setGroup("General");
return pConf->readBoolEntry(SHOW_WELCOME_ENTRY, true);
@@ -683,7 +683,7 @@ TQString KScopeConfig::getEditorPopupName() const
{
switch (m_cp.popup) {
case Embedded:
- return "ktexteditor_popup";
+ return "tdetexteditor_popup";
case KScopeOnly:
return "kscope_popup";
diff --git a/src/kscopeui.rc b/src/kscopeui.rc
index 81d3646..452cb65 100644
--- a/src/kscopeui.rc
+++ b/src/kscopeui.rc
@@ -77,7 +77,7 @@
<Separator/>
<Action name="query_close"/>
</Menu>
-<Menu name="ktexteditor_popup">
+<Menu name="tdetexteditor_popup">
<Merge/>
<Menu name="cscope"><text>Cscope</text>
<Action name="cscope_references"/>
diff --git a/src/main.cpp b/src/main.cpp
index ffa7b55..9d88dfc 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -25,9 +25,9 @@
*
***************************************************************************/
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <klocale.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
+#include <tdelocale.h>
#include "kscope.h"
#include "kscopeconfig.h"
@@ -36,13 +36,13 @@ static const char *description =
I18N_NOOP("KScope\nA source-editing environment for KDE, based on "
"Cscope");
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "+[CSCOPE.OUT path]",
I18N_NOOP("Opens a cscope.out file in a temporary project"), 0 },
{ "+[CSCOPE.PROJ path | KScope project directory path]",
I18N_NOOP("Opens a KScope project"), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
/**
@@ -55,8 +55,8 @@ static KCmdLineOptions options[] =
int main(int argc, char *argv[])
{
// Create the "About" dialogue
- KAboutData aboutData( "kscope", I18N_NOOP("KScope"),
- VERSION, description, KAboutData::License_BSD,
+ TDEAboutData aboutData( "kscope", I18N_NOOP("KScope"),
+ VERSION, description, TDEAboutData::License_BSD,
"(c) 2003-2007, Elad Lahav", 0, "http://kscope.sourceforge.net",
"elad_lahav@users.sf.net");
aboutData.addAuthor("Elad Lahav", "Developer",
@@ -67,14 +67,14 @@ int main(int argc, char *argv[])
"feketgai@index.hu");
// Initialise command-line argument parsing
- KCmdLineArgs::init(argc, argv, &aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
// Parse command line arguments
- KCmdLineArgs* pArgs = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs* pArgs = TDECmdLineArgs::parsedArgs();
// Create the main window
- KApplication a;
+ TDEApplication a;
KScope* pKScope = new KScope();
a.setMainWidget(pKScope);
diff --git a/src/makedlg.cpp b/src/makedlg.cpp
index 8bcc5ad..b11741a 100644
--- a/src/makedlg.cpp
+++ b/src/makedlg.cpp
@@ -29,8 +29,8 @@
#include <ktextbrowser.h>
#include <kcombobox.h>
#include <kurlrequester.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "makedlg.h"
#include "makefrontend.h"
#include "queryview.h"
diff --git a/src/newprojectdlg.cpp b/src/newprojectdlg.cpp
index cc1e73e..961cd3d 100644
--- a/src/newprojectdlg.cpp
+++ b/src/newprojectdlg.cpp
@@ -32,8 +32,8 @@
#include <ntqtextedit.h>
#include <kurlrequester.h>
#include <klineedit.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "newprojectdlg.h"
/**
diff --git a/src/preferencesdlg.cpp b/src/preferencesdlg.cpp
index 9540c73..f929383 100644
--- a/src/preferencesdlg.cpp
+++ b/src/preferencesdlg.cpp
@@ -26,14 +26,14 @@
***************************************************************************/
#include <ntqlayout.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kiconloader.h>
#include <kurlrequester.h>
#include <klineedit.h>
#include <ntqcheckbox.h>
#include <kcolorbutton.h>
-#include <kmessagebox.h>
-#include <kfontrequester.h>
+#include <tdemessagebox.h>
+#include <tdefontrequester.h>
#include "preferencesdlg.h"
#include "preffrontend.h"
#include "prefcolor.h"
@@ -62,29 +62,29 @@ PreferencesDlg::PreferencesDlg(uint nPage, TQWidget* pParent,
// Create and add the "Frontend" page
pFrame = addPage(i18n("Programmes"),
i18n("Paths to back-end programmes"),
- KGlobal::iconLoader()->loadIcon("run", KIcon::Panel, 0, false));
+ TDEGlobal::iconLoader()->loadIcon("run", TDEIcon::Panel, 0, false));
pLayout = new TQVBoxLayout(pFrame, 0, 0);
m_pPrefFrontend = new PrefFrontend(pFrame);
pLayout->addWidget(m_pPrefFrontend);
// Create and add the "Colours" page
pFrame = addPage(i18n("Colours"), i18n("Window colours"),
- KGlobal::iconLoader()->loadIcon("colors", KIcon::Panel, 0, false));
+ TDEGlobal::iconLoader()->loadIcon("colors", TDEIcon::Panel, 0, false));
pLayout = new TQVBoxLayout(pFrame, 0, 0);
m_pPrefColor = new PrefColor(pFrame);
pLayout->addWidget(m_pPrefColor);
// Create and add the "Fonts" page
pFrame = addPage(i18n("Fonts"), i18n("Window fonts"),
- KGlobal::iconLoader()->loadIcon("fonts", KIcon::Panel, 0, false));
+ TDEGlobal::iconLoader()->loadIcon("fonts", TDEIcon::Panel, 0, false));
pLayout = new TQVBoxLayout(pFrame, 0, 0);
m_pPrefFont = new PrefFont(pFrame);
pLayout->addWidget(m_pPrefFont);
// Create and add the "Options" page
pFrame = addPage(i18n("Options"), i18n("Misc. Options"),
- KGlobal::iconLoader()->loadIcon("package_settings",
- KIcon::Panel, 0, false));
+ TDEGlobal::iconLoader()->loadIcon("package_settings",
+ TDEIcon::Panel, 0, false));
pLayout = new TQVBoxLayout(pFrame, 0, 0);
m_pPrefOpt = new PrefOpt(pFrame);
pLayout->addWidget(m_pPrefOpt);
diff --git a/src/preffont.cpp b/src/preffont.cpp
index 0613b75..bbed937 100644
--- a/src/preffont.cpp
+++ b/src/preffont.cpp
@@ -27,8 +27,8 @@
#include <ntqlistview.h>
#include <ntqpainter.h>
-#include <kfontdialog.h>
-#include <klocale.h>
+#include <tdefontdialog.h>
+#include <tdelocale.h>
#include "preffont.h"
#include "kscopeconfig.h"
@@ -165,7 +165,7 @@ void PrefFont::slotItemSelected(TQListViewItem* pItem)
pFontItem = (FontListItem*)pItem;
font = pFontItem->getFont();
- if (KFontDialog::getFont(font) == TQDialog::Accepted) {
+ if (TDEFontDialog::getFont(font) == TQDialog::Accepted) {
pFontItem->setFont(font);
emit modified();
}
diff --git a/src/preffrontend.cpp b/src/preffrontend.cpp
index 526798f..6b3c9c5 100644
--- a/src/preffrontend.cpp
+++ b/src/preffrontend.cpp
@@ -30,7 +30,7 @@
#include <kurlrequester.h>
#include <klineedit.h>
#include <kstandarddirs.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "preffrontend.h"
#include "kscopeconfig.h"
#include "configfrontend.h"
diff --git a/src/project.cpp b/src/project.cpp
index 9e72648..2938778 100644
--- a/src/project.cpp
+++ b/src/project.cpp
@@ -28,8 +28,8 @@
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "project.h"
#include "kscopeconfig.h"
#include "cscopefrontend.h"
@@ -103,7 +103,7 @@ bool Project::open(const TQString& sPath)
m_fiFileList.setName(sPath + "/cscope.files");
// Open the configuration files
- m_pConf = new KConfig(sPath + "/cscope.proj");
+ m_pConf = new TDEConfig(sPath + "/cscope.proj");
// Verify the configuration file's version is compatible
m_pConf->setGroup("");
@@ -402,7 +402,7 @@ bool Project::create(const TQString& sName, const TQString& sPath,
const Options& opt)
{
// Prepare the project's files
- KConfig conf(sPath + "/cscope.proj");
+ TDEConfig conf(sPath + "/cscope.proj");
// Write the configuration file version
conf.setGroup("");
@@ -420,7 +420,7 @@ bool Project::create(const TQString& sName, const TQString& sPath,
return true;
}
-void Project::writeOptions(KConfig* pConf, const Options& opt)
+void Project::writeOptions(TDEConfig* pConf, const Options& opt)
{
pConf->setGroup("Project");
pConf->writeEntry("RootPath", opt.sSrcRootPath);
diff --git a/src/project.h b/src/project.h
index 5569490..bcca58a 100644
--- a/src/project.h
+++ b/src/project.h
@@ -76,7 +76,7 @@ public:
private:
/** The configuration file ("cscope.proj") */
- KConfig* m_pConf;
+ TDEConfig* m_pConf;
/** The file that holds the paths of all source files in this project
("cscope.files") */
@@ -86,7 +86,7 @@ private:
TQString m_sMakeRoot;
- static void writeOptions(KConfig*, const Options&);
+ static void writeOptions(TDEConfig*, const Options&);
};
#endif
diff --git a/src/projectbase.h b/src/projectbase.h
index eb0356d..5cd63e2 100644
--- a/src/projectbase.h
+++ b/src/projectbase.h
@@ -31,7 +31,7 @@
#include <ntqstringlist.h>
#include <ntqdir.h>
#include <ntqfile.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#define DEF_IS_KERNEL false
#define DEF_INV_INDEX true
diff --git a/src/projectfilesdlg.cpp b/src/projectfilesdlg.cpp
index badcdd1..5ff4987 100644
--- a/src/projectfilesdlg.cpp
+++ b/src/projectfilesdlg.cpp
@@ -29,9 +29,9 @@
#include <ntqlistview.h>
#include <ntqlineedit.h>
#include <ntqregexp.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
#include "projectfilesdlg.h"
#include "dirscanner.h"
#include "scanprogressdlg.h"
diff --git a/src/projectmanager.cpp b/src/projectmanager.cpp
index 252946d..6c38028 100644
--- a/src/projectmanager.cpp
+++ b/src/projectmanager.cpp
@@ -25,8 +25,8 @@
*
***************************************************************************/
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
#include "projectmanager.h"
#include "project.h"
#include "kscopeconfig.h"
diff --git a/src/querypage.cpp b/src/querypage.cpp
index c5e9b9a..d1ee2ff 100644
--- a/src/querypage.cpp
+++ b/src/querypage.cpp
@@ -26,7 +26,7 @@
***************************************************************************/
#include <ntqfile.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "querypage.h"
#include "queryview.h"
#include "queryviewdriver.h"
diff --git a/src/queryresultsmenu.cpp b/src/queryresultsmenu.cpp
index 0883ff6..2446d12 100644
--- a/src/queryresultsmenu.cpp
+++ b/src/queryresultsmenu.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <klocale.h>
+#include <tdelocale.h>
#include "queryresultsmenu.h"
/**
diff --git a/src/queryview.cpp b/src/queryview.cpp
index f791b5d..06567a4 100644
--- a/src/queryview.cpp
+++ b/src/queryview.cpp
@@ -27,7 +27,7 @@
#include <ntqapplication.h>
#include <ntqclipboard.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "queryview.h"
#include "queryresultsmenu.h"
#include "queryviewdlg.h"
diff --git a/src/queryviewdriver.cpp b/src/queryviewdriver.cpp
index 8c35238..eef943c 100644
--- a/src/queryviewdriver.cpp
+++ b/src/queryviewdriver.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <klocale.h>
+#include <tdelocale.h>
#include "queryviewdriver.h"
#include "queryview.h"
diff --git a/src/querywidget.cpp b/src/querywidget.cpp
index 2246c8e..ea55dca 100644
--- a/src/querywidget.cpp
+++ b/src/querywidget.cpp
@@ -27,8 +27,8 @@
#include <ntqtoolbutton.h>
#include <ntqtooltip.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
#include "querywidget.h"
#include "kscopepixmaps.h"
#include "kscopeconfig.h"
@@ -385,7 +385,7 @@ void QueryWidget::selectActiveHistory()
* @param pMenu Pointer to the popup menu
* @param pAction Pointer to the "Lock/Unlock" toggle action
*/
-void QueryWidget::setPageMenu(TQPopupMenu* pMenu, KToggleAction* pAction)
+void QueryWidget::setPageMenu(TQPopupMenu* pMenu, TDEToggleAction* pAction)
{
m_pPageMenu = pMenu;
m_pLockAction = pAction;
diff --git a/src/querywidget.h b/src/querywidget.h
index d309bb0..a362236 100644
--- a/src/querywidget.h
+++ b/src/querywidget.h
@@ -30,7 +30,7 @@
#include <ntqlistview.h>
#include <ntqpopupmenu.h>
-#include <kaction.h>
+#include <tdeaction.h>
#include "querywidgetlayout.h"
#include "tabwidget.h"
#include "querypage.h"
@@ -57,7 +57,7 @@ public:
void savePages(const TQString&, TQStringList&);
void addHistoryRecord(const TQString&, uint, const TQString&);
void selectActiveHistory();
- void setPageMenu(TQPopupMenu*, KToggleAction*);
+ void setPageMenu(TQPopupMenu*, TDEToggleAction*);
void getBookmarks(FileLocationList&);
/**
@@ -99,7 +99,7 @@ private:
TQPopupMenu* m_pPageMenu;
/** A toggle-like action for changing the locked state of a query. */
- KToggleAction* m_pLockAction;
+ TDEToggleAction* m_pLockAction;
/** The active history page. */
HistoryPage* m_pHistPage;
diff --git a/src/scanprogressdlg.cpp b/src/scanprogressdlg.cpp
index 243c3a4..0f98c1b 100644
--- a/src/scanprogressdlg.cpp
+++ b/src/scanprogressdlg.cpp
@@ -27,7 +27,7 @@
#include <ntqlabel.h>
#include <ntqpushbutton.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "scanprogressdlg.h"
/**
diff --git a/src/symbolcompletion.cpp b/src/symbolcompletion.cpp
index e385c07..d566b1b 100644
--- a/src/symbolcompletion.cpp
+++ b/src/symbolcompletion.cpp
@@ -26,7 +26,7 @@
***************************************************************************/
#include <ntqtimer.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "symbolcompletion.h"
bool SymbolCompletion::s_bACEnabled;
diff --git a/src/symbolcompletion.h b/src/symbolcompletion.h
index f25eb91..c540e12 100644
--- a/src/symbolcompletion.h
+++ b/src/symbolcompletion.h
@@ -30,8 +30,8 @@
#include <ntqobject.h>
#include <ntqregexp.h>
-#include <ktexteditor/codecompletioninterface.h>
-#include <ktexteditor/view.h>
+#include <tdetexteditor/codecompletioninterface.h>
+#include <tdetexteditor/view.h>
#include "cscopefrontend.h"
/**
diff --git a/src/symboldlg.cpp b/src/symboldlg.cpp
index 8ec631c..997f4bb 100644
--- a/src/symboldlg.cpp
+++ b/src/symboldlg.cpp
@@ -32,7 +32,7 @@
#include <ntqcheckbox.h>
#include <ntqgroupbox.h>
#include <kcombobox.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "symboldlg.h"
#include "cscopefrontend.h"
#include "kscopeconfig.h"
diff --git a/src/tabwidget.cpp b/src/tabwidget.cpp
index 57cfa84..bc9f00a 100644
--- a/src/tabwidget.cpp
+++ b/src/tabwidget.cpp
@@ -26,7 +26,7 @@
***************************************************************************/
#include <ntqtooltip.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include "tabwidget.h"
#include "kscopepixmaps.h"
diff --git a/src/kscopepixmaps.cpp b/src/kscopepixmaps.cpp
index 1eec922..31dca4b 100644
--- a/src/kscopepixmaps.cpp
+++ b/src/kscopepixmaps.cpp
@@ -25,7 +25,7 @@
*
***************************************************************************/
-#include <kglobal.h>
+#include <tdeglobal.h>
#include <kiconloader.h>
#include "kscopepixmaps.h"
@@ -287,7 +287,7 @@ const TQPixmap& KScopePixmaps::getPixmap(PixName name) const
}
/**
* Loads a pixmap with the KIconLoader mechanism.
* @param name The pixmap's identifier
* @return The requested pixmap
*/
@@ -295,71 +295,71 @@ TQPixmap KScopePixmaps::getPixmap(LoadPixName name)
{
switch (name) {
case TabUnlocked:
- return m_loader.loadIcon("query_unlocked", KIcon::Small, 0,
+ return m_loader.loadIcon("query_unlocked", TDEIcon::Small, 0,
false);
case TabLocked:
- return m_loader.loadIcon("query_locked", KIcon::Small, 0,
+ return m_loader.loadIcon("query_locked", TDEIcon::Small, 0,
false);
case TabBookmark:
- return m_loader.loadIcon("bookmark", KIcon::Small, 0,
+ return m_loader.loadIcon("bookmark", TDEIcon::Small, 0,
false);
case TabRW:
- return m_loader.loadIcon("file_rw", KIcon::Small, 0,
+ return m_loader.loadIcon("file_rw", TDEIcon::Small, 0,
false);
case TabRO:
- return m_loader.loadIcon("file_ro", KIcon::Small, 0,
+ return m_loader.loadIcon("file_ro", TDEIcon::Small, 0,
false);
case TabSave:
- return m_loader.loadIcon("file_save", KIcon::Small, 0,
+ return m_loader.loadIcon("file_save", TDEIcon::Small, 0,
false);
case TabFileList:
- return m_loader.loadIcon("view_detailed", KIcon::Small, 0,
+ return m_loader.loadIcon("view_detailed", TDEIcon::Small, 0,
false);
case TabFileTree:
- return m_loader.loadIcon("view_tree", KIcon::Small, 0,
+ return m_loader.loadIcon("view_tree", TDEIcon::Small, 0,
false);
case TabList:
- return m_loader.loadIcon("tab_list", KIcon::Small, 0,
+ return m_loader.loadIcon("tab_list", TDEIcon::Small, 0,
false);
case ButtonSaveAs:
- return m_loader.loadIcon("filesaveas", KIcon::Toolbar,
+ return m_loader.loadIcon("filesaveas", TDEIcon::Toolbar,
0, false);
case ButtonZoomIn:
- return m_loader.loadIcon("viewmag+", KIcon::Toolbar,
+ return m_loader.loadIcon("viewmag+", TDEIcon::Toolbar,
0, false);
case ButtonZoomOut:
- return m_loader.loadIcon("viewmag-", KIcon::Toolbar,
+ return m_loader.loadIcon("viewmag-", TDEIcon::Toolbar,
0, false);
case ButtonRotate:
- return m_loader.loadIcon("rotate", KIcon::Toolbar,
+ return m_loader.loadIcon("rotate", TDEIcon::Toolbar,
0, false);
case ButtonPref:
- return m_loader.loadIcon("configure", KIcon::Toolbar,
+ return m_loader.loadIcon("configure", TDEIcon::Toolbar,
0, false);
case CalledTree:
- return m_loader.loadIcon("called_tree", KIcon::Toolbar,
+ return m_loader.loadIcon("called_tree", TDEIcon::Toolbar,
0, false);
case CallingTree:
- return m_loader.loadIcon("calling_tree", KIcon::Toolbar,
+ return m_loader.loadIcon("calling_tree", TDEIcon::Toolbar,
0, false);
case CallGraph:
- return m_loader.loadIcon("call_graph", KIcon::Toolbar,
+ return m_loader.loadIcon("call_graph", TDEIcon::Toolbar,
0, false);
}
@@ -287,7 +287,7 @@ const TQPixmap& KScopePixmaps::getPixmap(PixName name) const
}
/**
- * Loads a pixmap with the KIconLoader mechanism.
+ * Loads a pixmap with the TDEIconLoader mechanism.
* @param name The pixmap's identifier
* @return The requested pixmap
diff --git a/src/kscopepixmaps.h b/src/kscopepixmaps.h
index 2577ef6..db27712 100644
--- a/src/kscopepixmaps.h
+++ b/src/kscopepixmaps.h
@@ -38,7 +38,7 @@
* Handles all pixmaps required by KScope.
* There are two types of pixmaps: embedded, i.e., pixmaps whose pixels are
* given by static two-dimensional arrays, and loadable, which are retrieved
* through the KIconLoader mechanism.
* The application uses a single global instance of this class.
* @author Elad Lahav
*/
@@ -69,7 +69,7 @@ private:
TQPixmap** m_pPixArray;
/** An icon loader used to retrieve pixmaps through the KDE mechanism. */
- KIconLoader m_loader;
+ TDEIconLoader m_loader;
};
extern KScopePixmaps& Pixmaps();
@@ -38,7 +38,7 @@
* There are two types of pixmaps: embedded, i.e., pixmaps whose pixels are
* given by static two-dimensional arrays, and loadable, which are retrieved
- * through the KIconLoader mechanism.
+ * through the TDEIconLoader mechanism.
* The application uses a single global instance of this class.
* @author Elad Lahav